@@ -1,6 +1,7 @@
 #include "launcher.h"
 #include "adapter.h"
 #include <QDeclarativeView>
+#include <QDebug>
 
 Launcher::Launcher(QObject *parent) :
     QObject(parent)
@@ -15,13 +16,14 @@ Launcher::Launcher(QObject *parent) :
 	}
 	if(!connection.registerService("org.openice.ughost.launcher"))
 	{
-		qDebug("org.openice.ughost.launcher");
+		qDebug("failed to register service: org.openice.ughost.launcher");
 		qDebug()<<connection.lastError().message();
 	}
 }
 
 void Launcher::LoadQml(QString path)
 {
+	qDebug()<<"trying to load: "<<path;
 	int childpid = vfork();
 	if(!childpid)
 	{
